# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRiskRulesResult',
    'AwaitableGetRiskRulesResult',
    'get_risk_rules',
    'get_risk_rules_output',
]

@pulumi.output_type
class GetRiskRulesResult:
    """
    A collection of values returned by getRiskRules.
    """
    def __init__(__self__, description=None, filter=None, filters=None, id=None, name=None, source=None, target=None, type=None):
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if filter and not isinstance(filter, list):
            raise TypeError("Expected argument 'filter' to be a list")
        pulumi.set(__self__, "filter", filter)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if source and not isinstance(source, dict):
            raise TypeError("Expected argument 'source' to be a dict")
        pulumi.set(__self__, "source", source)
        if target and not isinstance(target, str):
            raise TypeError("Expected argument 'target' to be a str")
        pulumi.set(__self__, "target", target)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def filter(self) -> Optional[Sequence['outputs.GetRiskRulesFilterResult']]:
        return pulumi.get(self, "filter")

    @property
    @pulumi.getter
    def filters(self) -> Sequence[str]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def source(self) -> 'outputs.GetRiskRulesSourceResult':
        return pulumi.get(self, "source")

    @property
    @pulumi.getter
    def target(self) -> str:
        return pulumi.get(self, "target")

    @property
    @pulumi.getter
    def type(self) -> str:
        return pulumi.get(self, "type")


class AwaitableGetRiskRulesResult(GetRiskRulesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRiskRulesResult(
            description=self.description,
            filter=self.filter,
            filters=self.filters,
            id=self.id,
            name=self.name,
            source=self.source,
            target=self.target,
            type=self.type)


def get_risk_rules(description: Optional[str] = None,
                   filter: Optional[Sequence[pulumi.InputType['GetRiskRulesFilterArgs']]] = None,
                   filters: Optional[Sequence[str]] = None,
                   name: Optional[str] = None,
                   source: Optional[pulumi.InputType['GetRiskRulesSourceArgs']] = None,
                   target: Optional[str] = None,
                   type: Optional[str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRiskRulesResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['description'] = description
    __args__['filter'] = filter
    __args__['filters'] = filters
    __args__['name'] = name
    __args__['source'] = source
    __args__['target'] = target
    __args__['type'] = type
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('onelogin:index/getRiskRules:getRiskRules', __args__, opts=opts, typ=GetRiskRulesResult).value

    return AwaitableGetRiskRulesResult(
        description=pulumi.get(__ret__, 'description'),
        filter=pulumi.get(__ret__, 'filter'),
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        source=pulumi.get(__ret__, 'source'),
        target=pulumi.get(__ret__, 'target'),
        type=pulumi.get(__ret__, 'type'))


@_utilities.lift_output_func(get_risk_rules)
def get_risk_rules_output(description: Optional[pulumi.Input[Optional[str]]] = None,
                          filter: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetRiskRulesFilterArgs']]]]] = None,
                          filters: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                          name: Optional[pulumi.Input[Optional[str]]] = None,
                          source: Optional[pulumi.Input[Optional[pulumi.InputType['GetRiskRulesSourceArgs']]]] = None,
                          target: Optional[pulumi.Input[Optional[str]]] = None,
                          type: Optional[pulumi.Input[Optional[str]]] = None,
                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRiskRulesResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetV1AppsResult',
    'AwaitableGetV1AppsResult',
    'get_v1_apps',
    'get_v1_apps_output',
]

@pulumi.output_type
class GetV1AppsResult:
    """
    A collection of values returned by getV1Apps.
    """
    def __init__(__self__, extension=None, filters=None, icon_url=None, id=None, login_id=None, name=None, provisioning_enabled=None, provisioning_state=None, provisioning_status=None, users_v1_id=None):
        if extension and not isinstance(extension, bool):
            raise TypeError("Expected argument 'extension' to be a bool")
        pulumi.set(__self__, "extension", extension)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if icon_url and not isinstance(icon_url, str):
            raise TypeError("Expected argument 'icon_url' to be a str")
        pulumi.set(__self__, "icon_url", icon_url)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if login_id and not isinstance(login_id, int):
            raise TypeError("Expected argument 'login_id' to be a int")
        pulumi.set(__self__, "login_id", login_id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if provisioning_enabled and not isinstance(provisioning_enabled, bool):
            raise TypeError("Expected argument 'provisioning_enabled' to be a bool")
        pulumi.set(__self__, "provisioning_enabled", provisioning_enabled)
        if provisioning_state and not isinstance(provisioning_state, str):
            raise TypeError("Expected argument 'provisioning_state' to be a str")
        pulumi.set(__self__, "provisioning_state", provisioning_state)
        if provisioning_status and not isinstance(provisioning_status, str):
            raise TypeError("Expected argument 'provisioning_status' to be a str")
        pulumi.set(__self__, "provisioning_status", provisioning_status)
        if users_v1_id and not isinstance(users_v1_id, str):
            raise TypeError("Expected argument 'users_v1_id' to be a str")
        pulumi.set(__self__, "users_v1_id", users_v1_id)

    @property
    @pulumi.getter
    def extension(self) -> bool:
        return pulumi.get(self, "extension")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetV1AppsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="iconUrl")
    def icon_url(self) -> str:
        return pulumi.get(self, "icon_url")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="loginId")
    def login_id(self) -> int:
        return pulumi.get(self, "login_id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="provisioningEnabled")
    def provisioning_enabled(self) -> bool:
        return pulumi.get(self, "provisioning_enabled")

    @property
    @pulumi.getter(name="provisioningState")
    def provisioning_state(self) -> str:
        return pulumi.get(self, "provisioning_state")

    @property
    @pulumi.getter(name="provisioningStatus")
    def provisioning_status(self) -> str:
        return pulumi.get(self, "provisioning_status")

    @property
    @pulumi.getter(name="usersV1Id")
    def users_v1_id(self) -> str:
        return pulumi.get(self, "users_v1_id")


class AwaitableGetV1AppsResult(GetV1AppsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetV1AppsResult(
            extension=self.extension,
            filters=self.filters,
            icon_url=self.icon_url,
            id=self.id,
            login_id=self.login_id,
            name=self.name,
            provisioning_enabled=self.provisioning_enabled,
            provisioning_state=self.provisioning_state,
            provisioning_status=self.provisioning_status,
            users_v1_id=self.users_v1_id)


def get_v1_apps(extension: Optional[bool] = None,
                filters: Optional[Sequence[pulumi.InputType['GetV1AppsFilterArgs']]] = None,
                icon_url: Optional[str] = None,
                login_id: Optional[int] = None,
                name: Optional[str] = None,
                provisioning_enabled: Optional[bool] = None,
                provisioning_state: Optional[str] = None,
                provisioning_status: Optional[str] = None,
                users_v1_id: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetV1AppsResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['extension'] = extension
    __args__['filters'] = filters
    __args__['iconUrl'] = icon_url
    __args__['loginId'] = login_id
    __args__['name'] = name
    __args__['provisioningEnabled'] = provisioning_enabled
    __args__['provisioningState'] = provisioning_state
    __args__['provisioningStatus'] = provisioning_status
    __args__['usersV1Id'] = users_v1_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('onelogin:users/getV1Apps:getV1Apps', __args__, opts=opts, typ=GetV1AppsResult).value

    return AwaitableGetV1AppsResult(
        extension=pulumi.get(__ret__, 'extension'),
        filters=pulumi.get(__ret__, 'filters'),
        icon_url=pulumi.get(__ret__, 'icon_url'),
        id=pulumi.get(__ret__, 'id'),
        login_id=pulumi.get(__ret__, 'login_id'),
        name=pulumi.get(__ret__, 'name'),
        provisioning_enabled=pulumi.get(__ret__, 'provisioning_enabled'),
        provisioning_state=pulumi.get(__ret__, 'provisioning_state'),
        provisioning_status=pulumi.get(__ret__, 'provisioning_status'),
        users_v1_id=pulumi.get(__ret__, 'users_v1_id'))


@_utilities.lift_output_func(get_v1_apps)
def get_v1_apps_output(extension: Optional[pulumi.Input[Optional[bool]]] = None,
                       filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetV1AppsFilterArgs']]]]] = None,
                       icon_url: Optional[pulumi.Input[Optional[str]]] = None,
                       login_id: Optional[pulumi.Input[Optional[int]]] = None,
                       name: Optional[pulumi.Input[Optional[str]]] = None,
                       provisioning_enabled: Optional[pulumi.Input[Optional[bool]]] = None,
                       provisioning_state: Optional[pulumi.Input[Optional[str]]] = None,
                       provisioning_status: Optional[pulumi.Input[Optional[str]]] = None,
                       users_v1_id: Optional[pulumi.Input[str]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetV1AppsResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RulesArgs', 'Rules']

@pulumi.input_type
class RulesArgs:
    def __init__(__self__, *,
                 apps_id: pulumi.Input[str],
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input['RulesActionArgs']]]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input['RulesConditionArgs']]]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 match: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 position: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Rules resource.
        :param pulumi.Input[Sequence[pulumi.Input['RulesConditionArgs']]] conditions: An array of conditions that the user must meet in order for the rule to be applied.
        :param pulumi.Input[bool] enabled: Indicates if the rule is enabled or not.
        :param pulumi.Input[str] match: Indicates how conditions should be matched.
        :param pulumi.Input[str] name: Rule Name
        :param pulumi.Input[int] position: Indicates the order of the rule. When `null` this will default to last position.
        """
        pulumi.set(__self__, "apps_id", apps_id)
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if match is not None:
            pulumi.set(__self__, "match", match)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if position is not None:
            pulumi.set(__self__, "position", position)

    @property
    @pulumi.getter(name="appsId")
    def apps_id(self) -> pulumi.Input[str]:
        return pulumi.get(self, "apps_id")

    @apps_id.setter
    def apps_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "apps_id", value)

    @property
    @pulumi.getter
    def actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RulesActionArgs']]]]:
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RulesActionArgs']]]]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RulesConditionArgs']]]]:
        """
        An array of conditions that the user must meet in order for the rule to be applied.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RulesConditionArgs']]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if the rule is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def match(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates how conditions should be matched.
        """
        return pulumi.get(self, "match")

    @match.setter
    def match(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "match", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Rule Name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def position(self) -> Optional[pulumi.Input[int]]:
        """
        Indicates the order of the rule. When `null` this will default to last position.
        """
        return pulumi.get(self, "position")

    @position.setter
    def position(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "position", value)


@pulumi.input_type
class _RulesState:
    def __init__(__self__, *,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input['RulesActionArgs']]]] = None,
                 apps_id: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input['RulesConditionArgs']]]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 match: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 position: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering Rules resources.
        :param pulumi.Input[Sequence[pulumi.Input['RulesConditionArgs']]] conditions: An array of conditions that the user must meet in order for the rule to be applied.
        :param pulumi.Input[bool] enabled: Indicates if the rule is enabled or not.
        :param pulumi.Input[str] match: Indicates how conditions should be matched.
        :param pulumi.Input[str] name: Rule Name
        :param pulumi.Input[int] position: Indicates the order of the rule. When `null` this will default to last position.
        """
        if actions is not None:
            pulumi.set(__self__, "actions", actions)
        if apps_id is not None:
            pulumi.set(__self__, "apps_id", apps_id)
        if conditions is not None:
            pulumi.set(__self__, "conditions", conditions)
        if enabled is not None:
            pulumi.set(__self__, "enabled", enabled)
        if match is not None:
            pulumi.set(__self__, "match", match)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if position is not None:
            pulumi.set(__self__, "position", position)

    @property
    @pulumi.getter
    def actions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RulesActionArgs']]]]:
        return pulumi.get(self, "actions")

    @actions.setter
    def actions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RulesActionArgs']]]]):
        pulumi.set(self, "actions", value)

    @property
    @pulumi.getter(name="appsId")
    def apps_id(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "apps_id")

    @apps_id.setter
    def apps_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "apps_id", value)

    @property
    @pulumi.getter
    def conditions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RulesConditionArgs']]]]:
        """
        An array of conditions that the user must meet in order for the rule to be applied.
        """
        return pulumi.get(self, "conditions")

    @conditions.setter
    def conditions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RulesConditionArgs']]]]):
        pulumi.set(self, "conditions", value)

    @property
    @pulumi.getter
    def enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if the rule is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enabled", value)

    @property
    @pulumi.getter
    def match(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates how conditions should be matched.
        """
        return pulumi.get(self, "match")

    @match.setter
    def match(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "match", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        Rule Name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def position(self) -> Optional[pulumi.Input[int]]:
        """
        Indicates the order of the rule. When `null` this will default to last position.
        """
        return pulumi.get(self, "position")

    @position.setter
    def position(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "position", value)


class Rules(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RulesActionArgs']]]]] = None,
                 apps_id: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RulesConditionArgs']]]]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 match: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 position: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Create a Rules resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RulesConditionArgs']]]] conditions: An array of conditions that the user must meet in order for the rule to be applied.
        :param pulumi.Input[bool] enabled: Indicates if the rule is enabled or not.
        :param pulumi.Input[str] match: Indicates how conditions should be matched.
        :param pulumi.Input[str] name: Rule Name
        :param pulumi.Input[int] position: Indicates the order of the rule. When `null` this will default to last position.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RulesArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a Rules resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param RulesArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RulesArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 actions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RulesActionArgs']]]]] = None,
                 apps_id: Optional[pulumi.Input[str]] = None,
                 conditions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RulesConditionArgs']]]]] = None,
                 enabled: Optional[pulumi.Input[bool]] = None,
                 match: Optional[pulumi.Input[str]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 position: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RulesArgs.__new__(RulesArgs)

            __props__.__dict__["actions"] = actions
            if apps_id is None and not opts.urn:
                raise TypeError("Missing required property 'apps_id'")
            __props__.__dict__["apps_id"] = apps_id
            __props__.__dict__["conditions"] = conditions
            __props__.__dict__["enabled"] = enabled
            __props__.__dict__["match"] = match
            __props__.__dict__["name"] = name
            __props__.__dict__["position"] = position
        super(Rules, __self__).__init__(
            'onelogin:apps/rules:Rules',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            actions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RulesActionArgs']]]]] = None,
            apps_id: Optional[pulumi.Input[str]] = None,
            conditions: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RulesConditionArgs']]]]] = None,
            enabled: Optional[pulumi.Input[bool]] = None,
            match: Optional[pulumi.Input[str]] = None,
            name: Optional[pulumi.Input[str]] = None,
            position: Optional[pulumi.Input[int]] = None) -> 'Rules':
        """
        Get an existing Rules resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['RulesConditionArgs']]]] conditions: An array of conditions that the user must meet in order for the rule to be applied.
        :param pulumi.Input[bool] enabled: Indicates if the rule is enabled or not.
        :param pulumi.Input[str] match: Indicates how conditions should be matched.
        :param pulumi.Input[str] name: Rule Name
        :param pulumi.Input[int] position: Indicates the order of the rule. When `null` this will default to last position.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RulesState.__new__(_RulesState)

        __props__.__dict__["actions"] = actions
        __props__.__dict__["apps_id"] = apps_id
        __props__.__dict__["conditions"] = conditions
        __props__.__dict__["enabled"] = enabled
        __props__.__dict__["match"] = match
        __props__.__dict__["name"] = name
        __props__.__dict__["position"] = position
        return Rules(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def actions(self) -> pulumi.Output[Optional[Sequence['outputs.RulesAction']]]:
        return pulumi.get(self, "actions")

    @property
    @pulumi.getter(name="appsId")
    def apps_id(self) -> pulumi.Output[str]:
        return pulumi.get(self, "apps_id")

    @property
    @pulumi.getter
    def conditions(self) -> pulumi.Output[Optional[Sequence['outputs.RulesCondition']]]:
        """
        An array of conditions that the user must meet in order for the rule to be applied.
        """
        return pulumi.get(self, "conditions")

    @property
    @pulumi.getter
    def enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates if the rule is enabled or not.
        """
        return pulumi.get(self, "enabled")

    @property
    @pulumi.getter
    def match(self) -> pulumi.Output[Optional[str]]:
        """
        Indicates how conditions should be matched.
        """
        return pulumi.get(self, "match")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        Rule Name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def position(self) -> pulumi.Output[Optional[int]]:
        """
        Indicates the order of the rule. When `null` this will default to last position.
        """
        return pulumi.get(self, "position")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetV1InstanceResult',
    'AwaitableGetV1InstanceResult',
    'get_v1_instance',
    'get_v1_instance_output',
]

@pulumi.output_type
class GetV1InstanceResult:
    """
    A collection of values returned by getV1Instance.
    """
    def __init__(__self__, activated_at=None, comment=None, company=None, created_at=None, department=None, directory_id=None, distinguished_name=None, email=None, external_id=None, firstname=None, group_id=None, id=None, invalid_login_attempts=None, invitation_sent_at=None, last_login=None, lastname=None, locked_until=None, manager_ad_id=None, manager_user_id=None, member_of=None, password=None, password_algorithm=None, password_changed_at=None, password_confirmation=None, phone=None, preferred_locale_code=None, role_ids=None, salt=None, samaccountname=None, state=None, status=None, title=None, trusted_idp_id=None, updated_at=None, username=None, userprincipalname=None):
        if activated_at and not isinstance(activated_at, str):
            raise TypeError("Expected argument 'activated_at' to be a str")
        pulumi.set(__self__, "activated_at", activated_at)
        if comment and not isinstance(comment, str):
            raise TypeError("Expected argument 'comment' to be a str")
        pulumi.set(__self__, "comment", comment)
        if company and not isinstance(company, str):
            raise TypeError("Expected argument 'company' to be a str")
        pulumi.set(__self__, "company", company)
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if department and not isinstance(department, str):
            raise TypeError("Expected argument 'department' to be a str")
        pulumi.set(__self__, "department", department)
        if directory_id and not isinstance(directory_id, int):
            raise TypeError("Expected argument 'directory_id' to be a int")
        pulumi.set(__self__, "directory_id", directory_id)
        if distinguished_name and not isinstance(distinguished_name, str):
            raise TypeError("Expected argument 'distinguished_name' to be a str")
        pulumi.set(__self__, "distinguished_name", distinguished_name)
        if email and not isinstance(email, str):
            raise TypeError("Expected argument 'email' to be a str")
        pulumi.set(__self__, "email", email)
        if external_id and not isinstance(external_id, str):
            raise TypeError("Expected argument 'external_id' to be a str")
        pulumi.set(__self__, "external_id", external_id)
        if firstname and not isinstance(firstname, str):
            raise TypeError("Expected argument 'firstname' to be a str")
        pulumi.set(__self__, "firstname", firstname)
        if group_id and not isinstance(group_id, int):
            raise TypeError("Expected argument 'group_id' to be a int")
        pulumi.set(__self__, "group_id", group_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if invalid_login_attempts and not isinstance(invalid_login_attempts, int):
            raise TypeError("Expected argument 'invalid_login_attempts' to be a int")
        pulumi.set(__self__, "invalid_login_attempts", invalid_login_attempts)
        if invitation_sent_at and not isinstance(invitation_sent_at, str):
            raise TypeError("Expected argument 'invitation_sent_at' to be a str")
        pulumi.set(__self__, "invitation_sent_at", invitation_sent_at)
        if last_login and not isinstance(last_login, str):
            raise TypeError("Expected argument 'last_login' to be a str")
        pulumi.set(__self__, "last_login", last_login)
        if lastname and not isinstance(lastname, str):
            raise TypeError("Expected argument 'lastname' to be a str")
        pulumi.set(__self__, "lastname", lastname)
        if locked_until and not isinstance(locked_until, str):
            raise TypeError("Expected argument 'locked_until' to be a str")
        pulumi.set(__self__, "locked_until", locked_until)
        if manager_ad_id and not isinstance(manager_ad_id, str):
            raise TypeError("Expected argument 'manager_ad_id' to be a str")
        pulumi.set(__self__, "manager_ad_id", manager_ad_id)
        if manager_user_id and not isinstance(manager_user_id, str):
            raise TypeError("Expected argument 'manager_user_id' to be a str")
        pulumi.set(__self__, "manager_user_id", manager_user_id)
        if member_of and not isinstance(member_of, str):
            raise TypeError("Expected argument 'member_of' to be a str")
        pulumi.set(__self__, "member_of", member_of)
        if password and not isinstance(password, str):
            raise TypeError("Expected argument 'password' to be a str")
        pulumi.set(__self__, "password", password)
        if password_algorithm and not isinstance(password_algorithm, str):
            raise TypeError("Expected argument 'password_algorithm' to be a str")
        pulumi.set(__self__, "password_algorithm", password_algorithm)
        if password_changed_at and not isinstance(password_changed_at, str):
            raise TypeError("Expected argument 'password_changed_at' to be a str")
        pulumi.set(__self__, "password_changed_at", password_changed_at)
        if password_confirmation and not isinstance(password_confirmation, str):
            raise TypeError("Expected argument 'password_confirmation' to be a str")
        pulumi.set(__self__, "password_confirmation", password_confirmation)
        if phone and not isinstance(phone, str):
            raise TypeError("Expected argument 'phone' to be a str")
        pulumi.set(__self__, "phone", phone)
        if preferred_locale_code and not isinstance(preferred_locale_code, str):
            raise TypeError("Expected argument 'preferred_locale_code' to be a str")
        pulumi.set(__self__, "preferred_locale_code", preferred_locale_code)
        if role_ids and not isinstance(role_ids, list):
            raise TypeError("Expected argument 'role_ids' to be a list")
        pulumi.set(__self__, "role_ids", role_ids)
        if salt and not isinstance(salt, str):
            raise TypeError("Expected argument 'salt' to be a str")
        pulumi.set(__self__, "salt", salt)
        if samaccountname and not isinstance(samaccountname, str):
            raise TypeError("Expected argument 'samaccountname' to be a str")
        pulumi.set(__self__, "samaccountname", samaccountname)
        if state and not isinstance(state, int):
            raise TypeError("Expected argument 'state' to be a int")
        pulumi.set(__self__, "state", state)
        if status and not isinstance(status, int):
            raise TypeError("Expected argument 'status' to be a int")
        pulumi.set(__self__, "status", status)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)
        if trusted_idp_id and not isinstance(trusted_idp_id, int):
            raise TypeError("Expected argument 'trusted_idp_id' to be a int")
        pulumi.set(__self__, "trusted_idp_id", trusted_idp_id)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)
        if userprincipalname and not isinstance(userprincipalname, str):
            raise TypeError("Expected argument 'userprincipalname' to be a str")
        pulumi.set(__self__, "userprincipalname", userprincipalname)

    @property
    @pulumi.getter(name="activatedAt")
    def activated_at(self) -> str:
        return pulumi.get(self, "activated_at")

    @property
    @pulumi.getter
    def comment(self) -> str:
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter
    def company(self) -> str:
        return pulumi.get(self, "company")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> str:
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def department(self) -> str:
        return pulumi.get(self, "department")

    @property
    @pulumi.getter(name="directoryId")
    def directory_id(self) -> int:
        return pulumi.get(self, "directory_id")

    @property
    @pulumi.getter(name="distinguishedName")
    def distinguished_name(self) -> str:
        return pulumi.get(self, "distinguished_name")

    @property
    @pulumi.getter
    def email(self) -> str:
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="externalId")
    def external_id(self) -> str:
        return pulumi.get(self, "external_id")

    @property
    @pulumi.getter
    def firstname(self) -> str:
        return pulumi.get(self, "firstname")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> int:
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="invalidLoginAttempts")
    def invalid_login_attempts(self) -> int:
        return pulumi.get(self, "invalid_login_attempts")

    @property
    @pulumi.getter(name="invitationSentAt")
    def invitation_sent_at(self) -> str:
        return pulumi.get(self, "invitation_sent_at")

    @property
    @pulumi.getter(name="lastLogin")
    def last_login(self) -> str:
        return pulumi.get(self, "last_login")

    @property
    @pulumi.getter
    def lastname(self) -> str:
        return pulumi.get(self, "lastname")

    @property
    @pulumi.getter(name="lockedUntil")
    def locked_until(self) -> str:
        return pulumi.get(self, "locked_until")

    @property
    @pulumi.getter(name="managerAdId")
    def manager_ad_id(self) -> str:
        return pulumi.get(self, "manager_ad_id")

    @property
    @pulumi.getter(name="managerUserId")
    def manager_user_id(self) -> str:
        return pulumi.get(self, "manager_user_id")

    @property
    @pulumi.getter(name="memberOf")
    def member_of(self) -> str:
        return pulumi.get(self, "member_of")

    @property
    @pulumi.getter
    def password(self) -> str:
        return pulumi.get(self, "password")

    @property
    @pulumi.getter(name="passwordAlgorithm")
    def password_algorithm(self) -> str:
        return pulumi.get(self, "password_algorithm")

    @property
    @pulumi.getter(name="passwordChangedAt")
    def password_changed_at(self) -> str:
        return pulumi.get(self, "password_changed_at")

    @property
    @pulumi.getter(name="passwordConfirmation")
    def password_confirmation(self) -> str:
        return pulumi.get(self, "password_confirmation")

    @property
    @pulumi.getter
    def phone(self) -> str:
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter(name="preferredLocaleCode")
    def preferred_locale_code(self) -> str:
        return pulumi.get(self, "preferred_locale_code")

    @property
    @pulumi.getter(name="roleIds")
    def role_ids(self) -> Sequence[int]:
        return pulumi.get(self, "role_ids")

    @property
    @pulumi.getter
    def salt(self) -> str:
        return pulumi.get(self, "salt")

    @property
    @pulumi.getter
    def samaccountname(self) -> str:
        return pulumi.get(self, "samaccountname")

    @property
    @pulumi.getter
    def state(self) -> int:
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def status(self) -> int:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def title(self) -> str:
        return pulumi.get(self, "title")

    @property
    @pulumi.getter(name="trustedIdpId")
    def trusted_idp_id(self) -> int:
        return pulumi.get(self, "trusted_idp_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> str:
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def username(self) -> str:
        return pulumi.get(self, "username")

    @property
    @pulumi.getter
    def userprincipalname(self) -> str:
        return pulumi.get(self, "userprincipalname")


class AwaitableGetV1InstanceResult(GetV1InstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetV1InstanceResult(
            activated_at=self.activated_at,
            comment=self.comment,
            company=self.company,
            created_at=self.created_at,
            department=self.department,
            directory_id=self.directory_id,
            distinguished_name=self.distinguished_name,
            email=self.email,
            external_id=self.external_id,
            firstname=self.firstname,
            group_id=self.group_id,
            id=self.id,
            invalid_login_attempts=self.invalid_login_attempts,
            invitation_sent_at=self.invitation_sent_at,
            last_login=self.last_login,
            lastname=self.lastname,
            locked_until=self.locked_until,
            manager_ad_id=self.manager_ad_id,
            manager_user_id=self.manager_user_id,
            member_of=self.member_of,
            password=self.password,
            password_algorithm=self.password_algorithm,
            password_changed_at=self.password_changed_at,
            password_confirmation=self.password_confirmation,
            phone=self.phone,
            preferred_locale_code=self.preferred_locale_code,
            role_ids=self.role_ids,
            salt=self.salt,
            samaccountname=self.samaccountname,
            state=self.state,
            status=self.status,
            title=self.title,
            trusted_idp_id=self.trusted_idp_id,
            updated_at=self.updated_at,
            username=self.username,
            userprincipalname=self.userprincipalname)


def get_v1_instance(activated_at: Optional[str] = None,
                    comment: Optional[str] = None,
                    company: Optional[str] = None,
                    created_at: Optional[str] = None,
                    department: Optional[str] = None,
                    directory_id: Optional[int] = None,
                    distinguished_name: Optional[str] = None,
                    email: Optional[str] = None,
                    external_id: Optional[str] = None,
                    firstname: Optional[str] = None,
                    group_id: Optional[int] = None,
                    id: Optional[str] = None,
                    invalid_login_attempts: Optional[int] = None,
                    invitation_sent_at: Optional[str] = None,
                    last_login: Optional[str] = None,
                    lastname: Optional[str] = None,
                    locked_until: Optional[str] = None,
                    manager_ad_id: Optional[str] = None,
                    manager_user_id: Optional[str] = None,
                    member_of: Optional[str] = None,
                    password: Optional[str] = None,
                    password_algorithm: Optional[str] = None,
                    password_changed_at: Optional[str] = None,
                    password_confirmation: Optional[str] = None,
                    phone: Optional[str] = None,
                    preferred_locale_code: Optional[str] = None,
                    role_ids: Optional[Sequence[int]] = None,
                    salt: Optional[str] = None,
                    samaccountname: Optional[str] = None,
                    state: Optional[int] = None,
                    status: Optional[int] = None,
                    title: Optional[str] = None,
                    trusted_idp_id: Optional[int] = None,
                    updated_at: Optional[str] = None,
                    username: Optional[str] = None,
                    userprincipalname: Optional[str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetV1InstanceResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['activatedAt'] = activated_at
    __args__['comment'] = comment
    __args__['company'] = company
    __args__['createdAt'] = created_at
    __args__['department'] = department
    __args__['directoryId'] = directory_id
    __args__['distinguishedName'] = distinguished_name
    __args__['email'] = email
    __args__['externalId'] = external_id
    __args__['firstname'] = firstname
    __args__['groupId'] = group_id
    __args__['id'] = id
    __args__['invalidLoginAttempts'] = invalid_login_attempts
    __args__['invitationSentAt'] = invitation_sent_at
    __args__['lastLogin'] = last_login
    __args__['lastname'] = lastname
    __args__['lockedUntil'] = locked_until
    __args__['managerAdId'] = manager_ad_id
    __args__['managerUserId'] = manager_user_id
    __args__['memberOf'] = member_of
    __args__['password'] = password
    __args__['passwordAlgorithm'] = password_algorithm
    __args__['passwordChangedAt'] = password_changed_at
    __args__['passwordConfirmation'] = password_confirmation
    __args__['phone'] = phone
    __args__['preferredLocaleCode'] = preferred_locale_code
    __args__['roleIds'] = role_ids
    __args__['salt'] = salt
    __args__['samaccountname'] = samaccountname
    __args__['state'] = state
    __args__['status'] = status
    __args__['title'] = title
    __args__['trustedIdpId'] = trusted_idp_id
    __args__['updatedAt'] = updated_at
    __args__['username'] = username
    __args__['userprincipalname'] = userprincipalname
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('onelogin:users/getV1Instance:getV1Instance', __args__, opts=opts, typ=GetV1InstanceResult).value

    return AwaitableGetV1InstanceResult(
        activated_at=pulumi.get(__ret__, 'activated_at'),
        comment=pulumi.get(__ret__, 'comment'),
        company=pulumi.get(__ret__, 'company'),
        created_at=pulumi.get(__ret__, 'created_at'),
        department=pulumi.get(__ret__, 'department'),
        directory_id=pulumi.get(__ret__, 'directory_id'),
        distinguished_name=pulumi.get(__ret__, 'distinguished_name'),
        email=pulumi.get(__ret__, 'email'),
        external_id=pulumi.get(__ret__, 'external_id'),
        firstname=pulumi.get(__ret__, 'firstname'),
        group_id=pulumi.get(__ret__, 'group_id'),
        id=pulumi.get(__ret__, 'id'),
        invalid_login_attempts=pulumi.get(__ret__, 'invalid_login_attempts'),
        invitation_sent_at=pulumi.get(__ret__, 'invitation_sent_at'),
        last_login=pulumi.get(__ret__, 'last_login'),
        lastname=pulumi.get(__ret__, 'lastname'),
        locked_until=pulumi.get(__ret__, 'locked_until'),
        manager_ad_id=pulumi.get(__ret__, 'manager_ad_id'),
        manager_user_id=pulumi.get(__ret__, 'manager_user_id'),
        member_of=pulumi.get(__ret__, 'member_of'),
        password=pulumi.get(__ret__, 'password'),
        password_algorithm=pulumi.get(__ret__, 'password_algorithm'),
        password_changed_at=pulumi.get(__ret__, 'password_changed_at'),
        password_confirmation=pulumi.get(__ret__, 'password_confirmation'),
        phone=pulumi.get(__ret__, 'phone'),
        preferred_locale_code=pulumi.get(__ret__, 'preferred_locale_code'),
        role_ids=pulumi.get(__ret__, 'role_ids'),
        salt=pulumi.get(__ret__, 'salt'),
        samaccountname=pulumi.get(__ret__, 'samaccountname'),
        state=pulumi.get(__ret__, 'state'),
        status=pulumi.get(__ret__, 'status'),
        title=pulumi.get(__ret__, 'title'),
        trusted_idp_id=pulumi.get(__ret__, 'trusted_idp_id'),
        updated_at=pulumi.get(__ret__, 'updated_at'),
        username=pulumi.get(__ret__, 'username'),
        userprincipalname=pulumi.get(__ret__, 'userprincipalname'))


@_utilities.lift_output_func(get_v1_instance)
def get_v1_instance_output(activated_at: Optional[pulumi.Input[Optional[str]]] = None,
                           comment: Optional[pulumi.Input[Optional[str]]] = None,
                           company: Optional[pulumi.Input[Optional[str]]] = None,
                           created_at: Optional[pulumi.Input[Optional[str]]] = None,
                           department: Optional[pulumi.Input[Optional[str]]] = None,
                           directory_id: Optional[pulumi.Input[Optional[int]]] = None,
                           distinguished_name: Optional[pulumi.Input[Optional[str]]] = None,
                           email: Optional[pulumi.Input[Optional[str]]] = None,
                           external_id: Optional[pulumi.Input[Optional[str]]] = None,
                           firstname: Optional[pulumi.Input[Optional[str]]] = None,
                           group_id: Optional[pulumi.Input[Optional[int]]] = None,
                           id: Optional[pulumi.Input[str]] = None,
                           invalid_login_attempts: Optional[pulumi.Input[Optional[int]]] = None,
                           invitation_sent_at: Optional[pulumi.Input[Optional[str]]] = None,
                           last_login: Optional[pulumi.Input[Optional[str]]] = None,
                           lastname: Optional[pulumi.Input[Optional[str]]] = None,
                           locked_until: Optional[pulumi.Input[Optional[str]]] = None,
                           manager_ad_id: Optional[pulumi.Input[Optional[str]]] = None,
                           manager_user_id: Optional[pulumi.Input[Optional[str]]] = None,
                           member_of: Optional[pulumi.Input[Optional[str]]] = None,
                           password: Optional[pulumi.Input[Optional[str]]] = None,
                           password_algorithm: Optional[pulumi.Input[Optional[str]]] = None,
                           password_changed_at: Optional[pulumi.Input[Optional[str]]] = None,
                           password_confirmation: Optional[pulumi.Input[Optional[str]]] = None,
                           phone: Optional[pulumi.Input[Optional[str]]] = None,
                           preferred_locale_code: Optional[pulumi.Input[Optional[str]]] = None,
                           role_ids: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                           salt: Optional[pulumi.Input[Optional[str]]] = None,
                           samaccountname: Optional[pulumi.Input[Optional[str]]] = None,
                           state: Optional[pulumi.Input[Optional[int]]] = None,
                           status: Optional[pulumi.Input[Optional[int]]] = None,
                           title: Optional[pulumi.Input[Optional[str]]] = None,
                           trusted_idp_id: Optional[pulumi.Input[Optional[int]]] = None,
                           updated_at: Optional[pulumi.Input[Optional[str]]] = None,
                           username: Optional[pulumi.Input[Optional[str]]] = None,
                           userprincipalname: Optional[pulumi.Input[Optional[str]]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetV1InstanceResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAuthServersScopesResult',
    'AwaitableGetAuthServersScopesResult',
    'get_auth_servers_scopes',
    'get_auth_servers_scopes_output',
]

@pulumi.output_type
class GetAuthServersScopesResult:
    """
    A collection of values returned by getAuthServersScopes.
    """
    def __init__(__self__, auth_servers_id=None, description=None, filters=None, id=None, value=None):
        if auth_servers_id and not isinstance(auth_servers_id, str):
            raise TypeError("Expected argument 'auth_servers_id' to be a str")
        pulumi.set(__self__, "auth_servers_id", auth_servers_id)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if value and not isinstance(value, str):
            raise TypeError("Expected argument 'value' to be a str")
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter(name="authServersId")
    def auth_servers_id(self) -> str:
        return pulumi.get(self, "auth_servers_id")

    @property
    @pulumi.getter
    def description(self) -> str:
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAuthServersScopesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def value(self) -> str:
        return pulumi.get(self, "value")


class AwaitableGetAuthServersScopesResult(GetAuthServersScopesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthServersScopesResult(
            auth_servers_id=self.auth_servers_id,
            description=self.description,
            filters=self.filters,
            id=self.id,
            value=self.value)


def get_auth_servers_scopes(auth_servers_id: Optional[str] = None,
                            description: Optional[str] = None,
                            filters: Optional[Sequence[pulumi.InputType['GetAuthServersScopesFilterArgs']]] = None,
                            value: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthServersScopesResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['authServersId'] = auth_servers_id
    __args__['description'] = description
    __args__['filters'] = filters
    __args__['value'] = value
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('onelogin:index/getAuthServersScopes:getAuthServersScopes', __args__, opts=opts, typ=GetAuthServersScopesResult).value

    return AwaitableGetAuthServersScopesResult(
        auth_servers_id=pulumi.get(__ret__, 'auth_servers_id'),
        description=pulumi.get(__ret__, 'description'),
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        value=pulumi.get(__ret__, 'value'))


@_utilities.lift_output_func(get_auth_servers_scopes)
def get_auth_servers_scopes_output(auth_servers_id: Optional[pulumi.Input[str]] = None,
                                   description: Optional[pulumi.Input[Optional[str]]] = None,
                                   filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAuthServersScopesFilterArgs']]]]] = None,
                                   value: Optional[pulumi.Input[Optional[str]]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAuthServersScopesResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAuthServersClaimsResult',
    'AwaitableGetAuthServersClaimsResult',
    'get_auth_servers_claims',
    'get_auth_servers_claims_output',
]

@pulumi.output_type
class GetAuthServersClaimsResult:
    """
    A collection of values returned by getAuthServersClaims.
    """
    def __init__(__self__, attribute_transformations=None, auth_servers_id=None, default_values=None, filters=None, id=None, label=None, provisioned_entitlements=None, skip_if_blank=None, user_attribute_macros=None, user_attribute_mappings=None, values=None):
        if attribute_transformations and not isinstance(attribute_transformations, str):
            raise TypeError("Expected argument 'attribute_transformations' to be a str")
        pulumi.set(__self__, "attribute_transformations", attribute_transformations)
        if auth_servers_id and not isinstance(auth_servers_id, str):
            raise TypeError("Expected argument 'auth_servers_id' to be a str")
        pulumi.set(__self__, "auth_servers_id", auth_servers_id)
        if default_values and not isinstance(default_values, str):
            raise TypeError("Expected argument 'default_values' to be a str")
        pulumi.set(__self__, "default_values", default_values)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if label and not isinstance(label, str):
            raise TypeError("Expected argument 'label' to be a str")
        pulumi.set(__self__, "label", label)
        if provisioned_entitlements and not isinstance(provisioned_entitlements, bool):
            raise TypeError("Expected argument 'provisioned_entitlements' to be a bool")
        pulumi.set(__self__, "provisioned_entitlements", provisioned_entitlements)
        if skip_if_blank and not isinstance(skip_if_blank, bool):
            raise TypeError("Expected argument 'skip_if_blank' to be a bool")
        pulumi.set(__self__, "skip_if_blank", skip_if_blank)
        if user_attribute_macros and not isinstance(user_attribute_macros, str):
            raise TypeError("Expected argument 'user_attribute_macros' to be a str")
        pulumi.set(__self__, "user_attribute_macros", user_attribute_macros)
        if user_attribute_mappings and not isinstance(user_attribute_mappings, str):
            raise TypeError("Expected argument 'user_attribute_mappings' to be a str")
        pulumi.set(__self__, "user_attribute_mappings", user_attribute_mappings)
        if values and not isinstance(values, list):
            raise TypeError("Expected argument 'values' to be a list")
        pulumi.set(__self__, "values", values)

    @property
    @pulumi.getter(name="attributeTransformations")
    def attribute_transformations(self) -> str:
        return pulumi.get(self, "attribute_transformations")

    @property
    @pulumi.getter(name="authServersId")
    def auth_servers_id(self) -> str:
        return pulumi.get(self, "auth_servers_id")

    @property
    @pulumi.getter(name="defaultValues")
    def default_values(self) -> str:
        return pulumi.get(self, "default_values")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAuthServersClaimsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def label(self) -> str:
        return pulumi.get(self, "label")

    @property
    @pulumi.getter(name="provisionedEntitlements")
    def provisioned_entitlements(self) -> bool:
        return pulumi.get(self, "provisioned_entitlements")

    @property
    @pulumi.getter(name="skipIfBlank")
    def skip_if_blank(self) -> bool:
        return pulumi.get(self, "skip_if_blank")

    @property
    @pulumi.getter(name="userAttributeMacros")
    def user_attribute_macros(self) -> str:
        return pulumi.get(self, "user_attribute_macros")

    @property
    @pulumi.getter(name="userAttributeMappings")
    def user_attribute_mappings(self) -> str:
        return pulumi.get(self, "user_attribute_mappings")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")


class AwaitableGetAuthServersClaimsResult(GetAuthServersClaimsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAuthServersClaimsResult(
            attribute_transformations=self.attribute_transformations,
            auth_servers_id=self.auth_servers_id,
            default_values=self.default_values,
            filters=self.filters,
            id=self.id,
            label=self.label,
            provisioned_entitlements=self.provisioned_entitlements,
            skip_if_blank=self.skip_if_blank,
            user_attribute_macros=self.user_attribute_macros,
            user_attribute_mappings=self.user_attribute_mappings,
            values=self.values)


def get_auth_servers_claims(attribute_transformations: Optional[str] = None,
                            auth_servers_id: Optional[str] = None,
                            default_values: Optional[str] = None,
                            filters: Optional[Sequence[pulumi.InputType['GetAuthServersClaimsFilterArgs']]] = None,
                            label: Optional[str] = None,
                            provisioned_entitlements: Optional[bool] = None,
                            skip_if_blank: Optional[bool] = None,
                            user_attribute_macros: Optional[str] = None,
                            user_attribute_mappings: Optional[str] = None,
                            values: Optional[Sequence[str]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAuthServersClaimsResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['attributeTransformations'] = attribute_transformations
    __args__['authServersId'] = auth_servers_id
    __args__['defaultValues'] = default_values
    __args__['filters'] = filters
    __args__['label'] = label
    __args__['provisionedEntitlements'] = provisioned_entitlements
    __args__['skipIfBlank'] = skip_if_blank
    __args__['userAttributeMacros'] = user_attribute_macros
    __args__['userAttributeMappings'] = user_attribute_mappings
    __args__['values'] = values
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('onelogin:index/getAuthServersClaims:getAuthServersClaims', __args__, opts=opts, typ=GetAuthServersClaimsResult).value

    return AwaitableGetAuthServersClaimsResult(
        attribute_transformations=pulumi.get(__ret__, 'attribute_transformations'),
        auth_servers_id=pulumi.get(__ret__, 'auth_servers_id'),
        default_values=pulumi.get(__ret__, 'default_values'),
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        label=pulumi.get(__ret__, 'label'),
        provisioned_entitlements=pulumi.get(__ret__, 'provisioned_entitlements'),
        skip_if_blank=pulumi.get(__ret__, 'skip_if_blank'),
        user_attribute_macros=pulumi.get(__ret__, 'user_attribute_macros'),
        user_attribute_mappings=pulumi.get(__ret__, 'user_attribute_mappings'),
        values=pulumi.get(__ret__, 'values'))


@_utilities.lift_output_func(get_auth_servers_claims)
def get_auth_servers_claims_output(attribute_transformations: Optional[pulumi.Input[Optional[str]]] = None,
                                   auth_servers_id: Optional[pulumi.Input[str]] = None,
                                   default_values: Optional[pulumi.Input[Optional[str]]] = None,
                                   filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAuthServersClaimsFilterArgs']]]]] = None,
                                   label: Optional[pulumi.Input[Optional[str]]] = None,
                                   provisioned_entitlements: Optional[pulumi.Input[Optional[bool]]] = None,
                                   skip_if_blank: Optional[pulumi.Input[Optional[bool]]] = None,
                                   user_attribute_macros: Optional[pulumi.Input[Optional[str]]] = None,
                                   user_attribute_mappings: Optional[pulumi.Input[Optional[str]]] = None,
                                   values: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAuthServersClaimsResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AppArgs', 'App']

@pulumi.input_type
class AppArgs:
    def __init__(__self__, *,
                 connector_id: pulumi.Input[int],
                 allow_assumed_signin: Optional[pulumi.Input[bool]] = None,
                 auth_method: Optional[pulumi.Input[int]] = None,
                 auth_method_description: Optional[pulumi.Input[str]] = None,
                 brand_id: Optional[pulumi.Input[int]] = None,
                 configuration: Optional[pulumi.Input['AppConfigurationArgs']] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enforcement_point: Optional[pulumi.Input['AppEnforcementPointArgs']] = None,
                 icon_url: Optional[pulumi.Input[str]] = None,
                 login_config: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input['AppParametersArgs']] = None,
                 policy_id: Optional[pulumi.Input[int]] = None,
                 provisioning: Optional[pulumi.Input['AppProvisioningArgs']] = None,
                 role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 sso: Optional[pulumi.Input['AppSsoArgs']] = None,
                 tab_id: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 visible: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a App resource.
        :param pulumi.Input[int] connector_id: ID of the connector to base the app from.
        :param pulumi.Input[bool] allow_assumed_signin: Indicates whether or not administrators can access the app as a user that they have assumed control over.
        :param pulumi.Input[int] auth_method: An ID indicating the type of app: - 0: Password - 1: OpenId - 2: SAML - 3: API - 4: Google - 6: Forms Based App - 7:
               WSFED - 8: OpenId Connect
        :param pulumi.Input['AppConfigurationArgs'] configuration: Only apply configurations that are applicable to the type of app
        :param pulumi.Input[str] created_at: the date the app was created
        :param pulumi.Input[str] description: Freeform description of the app.
        :param pulumi.Input['AppEnforcementPointArgs'] enforcement_point: For apps that connect to a OneLogin Access Enforcement Point the following enforcement_point object will be included
               with the app payload.
        :param pulumi.Input[str] icon_url: A link to the apps icon url
        :param pulumi.Input[str] name: The name of the app.
        :param pulumi.Input[str] notes: Freeform notes about the app.
        :param pulumi.Input[int] policy_id: The security policy assigned to the app.
        :param pulumi.Input['AppProvisioningArgs'] provisioning: Indicates if provisioning is enabled for this app.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] role_ids: List of Role IDs that are assigned to the app. On App Create or Update the entire array is replaced with the values
               provided.
        :param pulumi.Input['AppSsoArgs'] sso: The attributes included in the sso section are determined by the type of app. All of the attributes of the `sso` object
               are read only.
        :param pulumi.Input[int] tab_id: ID of the OneLogin portal tab that the app is assigned to.
        :param pulumi.Input[str] updated_at: the date the app was last updated
        :param pulumi.Input[bool] visible: Indicates if the app is visible in the OneLogin portal.
        """
        pulumi.set(__self__, "connector_id", connector_id)
        if allow_assumed_signin is not None:
            pulumi.set(__self__, "allow_assumed_signin", allow_assumed_signin)
        if auth_method is not None:
            pulumi.set(__self__, "auth_method", auth_method)
        if auth_method_description is not None:
            pulumi.set(__self__, "auth_method_description", auth_method_description)
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if configuration is not None:
            pulumi.set(__self__, "configuration", configuration)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enforcement_point is not None:
            pulumi.set(__self__, "enforcement_point", enforcement_point)
        if icon_url is not None:
            pulumi.set(__self__, "icon_url", icon_url)
        if login_config is not None:
            pulumi.set(__self__, "login_config", login_config)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notes is not None:
            pulumi.set(__self__, "notes", notes)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if provisioning is not None:
            pulumi.set(__self__, "provisioning", provisioning)
        if role_ids is not None:
            pulumi.set(__self__, "role_ids", role_ids)
        if sso is not None:
            pulumi.set(__self__, "sso", sso)
        if tab_id is not None:
            pulumi.set(__self__, "tab_id", tab_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if visible is not None:
            pulumi.set(__self__, "visible", visible)

    @property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> pulumi.Input[int]:
        """
        ID of the connector to base the app from.
        """
        return pulumi.get(self, "connector_id")

    @connector_id.setter
    def connector_id(self, value: pulumi.Input[int]):
        pulumi.set(self, "connector_id", value)

    @property
    @pulumi.getter(name="allowAssumedSignin")
    def allow_assumed_signin(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not administrators can access the app as a user that they have assumed control over.
        """
        return pulumi.get(self, "allow_assumed_signin")

    @allow_assumed_signin.setter
    def allow_assumed_signin(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_assumed_signin", value)

    @property
    @pulumi.getter(name="authMethod")
    def auth_method(self) -> Optional[pulumi.Input[int]]:
        """
        An ID indicating the type of app: - 0: Password - 1: OpenId - 2: SAML - 3: API - 4: Google - 6: Forms Based App - 7:
        WSFED - 8: OpenId Connect
        """
        return pulumi.get(self, "auth_method")

    @auth_method.setter
    def auth_method(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "auth_method", value)

    @property
    @pulumi.getter(name="authMethodDescription")
    def auth_method_description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "auth_method_description")

    @auth_method_description.setter
    def auth_method_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_method_description", value)

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "brand_id", value)

    @property
    @pulumi.getter
    def configuration(self) -> Optional[pulumi.Input['AppConfigurationArgs']]:
        """
        Only apply configurations that are applicable to the type of app
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: Optional[pulumi.Input['AppConfigurationArgs']]):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        the date the app was created
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Freeform description of the app.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enforcementPoint")
    def enforcement_point(self) -> Optional[pulumi.Input['AppEnforcementPointArgs']]:
        """
        For apps that connect to a OneLogin Access Enforcement Point the following enforcement_point object will be included
        with the app payload.
        """
        return pulumi.get(self, "enforcement_point")

    @enforcement_point.setter
    def enforcement_point(self, value: Optional[pulumi.Input['AppEnforcementPointArgs']]):
        pulumi.set(self, "enforcement_point", value)

    @property
    @pulumi.getter(name="iconUrl")
    def icon_url(self) -> Optional[pulumi.Input[str]]:
        """
        A link to the apps icon url
        """
        return pulumi.get(self, "icon_url")

    @icon_url.setter
    def icon_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "icon_url", value)

    @property
    @pulumi.getter(name="loginConfig")
    def login_config(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "login_config")

    @login_config.setter
    def login_config(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "login_config", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the app.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def notes(self) -> Optional[pulumi.Input[str]]:
        """
        Freeform notes about the app.
        """
        return pulumi.get(self, "notes")

    @notes.setter
    def notes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notes", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input['AppParametersArgs']]:
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input['AppParametersArgs']]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[int]]:
        """
        The security policy assigned to the app.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "policy_id", value)

    @property
    @pulumi.getter
    def provisioning(self) -> Optional[pulumi.Input['AppProvisioningArgs']]:
        """
        Indicates if provisioning is enabled for this app.
        """
        return pulumi.get(self, "provisioning")

    @provisioning.setter
    def provisioning(self, value: Optional[pulumi.Input['AppProvisioningArgs']]):
        pulumi.set(self, "provisioning", value)

    @property
    @pulumi.getter(name="roleIds")
    def role_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        List of Role IDs that are assigned to the app. On App Create or Update the entire array is replaced with the values
        provided.
        """
        return pulumi.get(self, "role_ids")

    @role_ids.setter
    def role_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "role_ids", value)

    @property
    @pulumi.getter
    def sso(self) -> Optional[pulumi.Input['AppSsoArgs']]:
        """
        The attributes included in the sso section are determined by the type of app. All of the attributes of the `sso` object
        are read only.
        """
        return pulumi.get(self, "sso")

    @sso.setter
    def sso(self, value: Optional[pulumi.Input['AppSsoArgs']]):
        pulumi.set(self, "sso", value)

    @property
    @pulumi.getter(name="tabId")
    def tab_id(self) -> Optional[pulumi.Input[int]]:
        """
        ID of the OneLogin portal tab that the app is assigned to.
        """
        return pulumi.get(self, "tab_id")

    @tab_id.setter
    def tab_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tab_id", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        the date the app was last updated
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def visible(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if the app is visible in the OneLogin portal.
        """
        return pulumi.get(self, "visible")

    @visible.setter
    def visible(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "visible", value)


@pulumi.input_type
class _AppState:
    def __init__(__self__, *,
                 allow_assumed_signin: Optional[pulumi.Input[bool]] = None,
                 auth_method: Optional[pulumi.Input[int]] = None,
                 auth_method_description: Optional[pulumi.Input[str]] = None,
                 brand_id: Optional[pulumi.Input[int]] = None,
                 configuration: Optional[pulumi.Input['AppConfigurationArgs']] = None,
                 connector_id: Optional[pulumi.Input[int]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enforcement_point: Optional[pulumi.Input['AppEnforcementPointArgs']] = None,
                 icon_url: Optional[pulumi.Input[str]] = None,
                 login_config: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input['AppParametersArgs']] = None,
                 policy_id: Optional[pulumi.Input[int]] = None,
                 provisioning: Optional[pulumi.Input['AppProvisioningArgs']] = None,
                 role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 sso: Optional[pulumi.Input['AppSsoArgs']] = None,
                 tab_id: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 visible: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering App resources.
        :param pulumi.Input[bool] allow_assumed_signin: Indicates whether or not administrators can access the app as a user that they have assumed control over.
        :param pulumi.Input[int] auth_method: An ID indicating the type of app: - 0: Password - 1: OpenId - 2: SAML - 3: API - 4: Google - 6: Forms Based App - 7:
               WSFED - 8: OpenId Connect
        :param pulumi.Input['AppConfigurationArgs'] configuration: Only apply configurations that are applicable to the type of app
        :param pulumi.Input[int] connector_id: ID of the connector to base the app from.
        :param pulumi.Input[str] created_at: the date the app was created
        :param pulumi.Input[str] description: Freeform description of the app.
        :param pulumi.Input['AppEnforcementPointArgs'] enforcement_point: For apps that connect to a OneLogin Access Enforcement Point the following enforcement_point object will be included
               with the app payload.
        :param pulumi.Input[str] icon_url: A link to the apps icon url
        :param pulumi.Input[str] name: The name of the app.
        :param pulumi.Input[str] notes: Freeform notes about the app.
        :param pulumi.Input[int] policy_id: The security policy assigned to the app.
        :param pulumi.Input['AppProvisioningArgs'] provisioning: Indicates if provisioning is enabled for this app.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] role_ids: List of Role IDs that are assigned to the app. On App Create or Update the entire array is replaced with the values
               provided.
        :param pulumi.Input['AppSsoArgs'] sso: The attributes included in the sso section are determined by the type of app. All of the attributes of the `sso` object
               are read only.
        :param pulumi.Input[int] tab_id: ID of the OneLogin portal tab that the app is assigned to.
        :param pulumi.Input[str] updated_at: the date the app was last updated
        :param pulumi.Input[bool] visible: Indicates if the app is visible in the OneLogin portal.
        """
        if allow_assumed_signin is not None:
            pulumi.set(__self__, "allow_assumed_signin", allow_assumed_signin)
        if auth_method is not None:
            pulumi.set(__self__, "auth_method", auth_method)
        if auth_method_description is not None:
            pulumi.set(__self__, "auth_method_description", auth_method_description)
        if brand_id is not None:
            pulumi.set(__self__, "brand_id", brand_id)
        if configuration is not None:
            pulumi.set(__self__, "configuration", configuration)
        if connector_id is not None:
            pulumi.set(__self__, "connector_id", connector_id)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enforcement_point is not None:
            pulumi.set(__self__, "enforcement_point", enforcement_point)
        if icon_url is not None:
            pulumi.set(__self__, "icon_url", icon_url)
        if login_config is not None:
            pulumi.set(__self__, "login_config", login_config)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if notes is not None:
            pulumi.set(__self__, "notes", notes)
        if parameters is not None:
            pulumi.set(__self__, "parameters", parameters)
        if policy_id is not None:
            pulumi.set(__self__, "policy_id", policy_id)
        if provisioning is not None:
            pulumi.set(__self__, "provisioning", provisioning)
        if role_ids is not None:
            pulumi.set(__self__, "role_ids", role_ids)
        if sso is not None:
            pulumi.set(__self__, "sso", sso)
        if tab_id is not None:
            pulumi.set(__self__, "tab_id", tab_id)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if visible is not None:
            pulumi.set(__self__, "visible", visible)

    @property
    @pulumi.getter(name="allowAssumedSignin")
    def allow_assumed_signin(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether or not administrators can access the app as a user that they have assumed control over.
        """
        return pulumi.get(self, "allow_assumed_signin")

    @allow_assumed_signin.setter
    def allow_assumed_signin(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "allow_assumed_signin", value)

    @property
    @pulumi.getter(name="authMethod")
    def auth_method(self) -> Optional[pulumi.Input[int]]:
        """
        An ID indicating the type of app: - 0: Password - 1: OpenId - 2: SAML - 3: API - 4: Google - 6: Forms Based App - 7:
        WSFED - 8: OpenId Connect
        """
        return pulumi.get(self, "auth_method")

    @auth_method.setter
    def auth_method(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "auth_method", value)

    @property
    @pulumi.getter(name="authMethodDescription")
    def auth_method_description(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "auth_method_description")

    @auth_method_description.setter
    def auth_method_description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_method_description", value)

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "brand_id")

    @brand_id.setter
    def brand_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "brand_id", value)

    @property
    @pulumi.getter
    def configuration(self) -> Optional[pulumi.Input['AppConfigurationArgs']]:
        """
        Only apply configurations that are applicable to the type of app
        """
        return pulumi.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: Optional[pulumi.Input['AppConfigurationArgs']]):
        pulumi.set(self, "configuration", value)

    @property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> Optional[pulumi.Input[int]]:
        """
        ID of the connector to base the app from.
        """
        return pulumi.get(self, "connector_id")

    @connector_id.setter
    def connector_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "connector_id", value)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[str]]:
        """
        the date the app was created
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "created_at", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Freeform description of the app.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enforcementPoint")
    def enforcement_point(self) -> Optional[pulumi.Input['AppEnforcementPointArgs']]:
        """
        For apps that connect to a OneLogin Access Enforcement Point the following enforcement_point object will be included
        with the app payload.
        """
        return pulumi.get(self, "enforcement_point")

    @enforcement_point.setter
    def enforcement_point(self, value: Optional[pulumi.Input['AppEnforcementPointArgs']]):
        pulumi.set(self, "enforcement_point", value)

    @property
    @pulumi.getter(name="iconUrl")
    def icon_url(self) -> Optional[pulumi.Input[str]]:
        """
        A link to the apps icon url
        """
        return pulumi.get(self, "icon_url")

    @icon_url.setter
    def icon_url(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "icon_url", value)

    @property
    @pulumi.getter(name="loginConfig")
    def login_config(self) -> Optional[pulumi.Input[int]]:
        return pulumi.get(self, "login_config")

    @login_config.setter
    def login_config(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "login_config", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the app.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def notes(self) -> Optional[pulumi.Input[str]]:
        """
        Freeform notes about the app.
        """
        return pulumi.get(self, "notes")

    @notes.setter
    def notes(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "notes", value)

    @property
    @pulumi.getter
    def parameters(self) -> Optional[pulumi.Input['AppParametersArgs']]:
        return pulumi.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: Optional[pulumi.Input['AppParametersArgs']]):
        pulumi.set(self, "parameters", value)

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> Optional[pulumi.Input[int]]:
        """
        The security policy assigned to the app.
        """
        return pulumi.get(self, "policy_id")

    @policy_id.setter
    def policy_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "policy_id", value)

    @property
    @pulumi.getter
    def provisioning(self) -> Optional[pulumi.Input['AppProvisioningArgs']]:
        """
        Indicates if provisioning is enabled for this app.
        """
        return pulumi.get(self, "provisioning")

    @provisioning.setter
    def provisioning(self, value: Optional[pulumi.Input['AppProvisioningArgs']]):
        pulumi.set(self, "provisioning", value)

    @property
    @pulumi.getter(name="roleIds")
    def role_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]:
        """
        List of Role IDs that are assigned to the app. On App Create or Update the entire array is replaced with the values
        provided.
        """
        return pulumi.get(self, "role_ids")

    @role_ids.setter
    def role_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]]):
        pulumi.set(self, "role_ids", value)

    @property
    @pulumi.getter
    def sso(self) -> Optional[pulumi.Input['AppSsoArgs']]:
        """
        The attributes included in the sso section are determined by the type of app. All of the attributes of the `sso` object
        are read only.
        """
        return pulumi.get(self, "sso")

    @sso.setter
    def sso(self, value: Optional[pulumi.Input['AppSsoArgs']]):
        pulumi.set(self, "sso", value)

    @property
    @pulumi.getter(name="tabId")
    def tab_id(self) -> Optional[pulumi.Input[int]]:
        """
        ID of the OneLogin portal tab that the app is assigned to.
        """
        return pulumi.get(self, "tab_id")

    @tab_id.setter
    def tab_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "tab_id", value)

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[str]]:
        """
        the date the app was last updated
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "updated_at", value)

    @property
    @pulumi.getter
    def visible(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates if the app is visible in the OneLogin portal.
        """
        return pulumi.get(self, "visible")

    @visible.setter
    def visible(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "visible", value)


class App(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_assumed_signin: Optional[pulumi.Input[bool]] = None,
                 auth_method: Optional[pulumi.Input[int]] = None,
                 auth_method_description: Optional[pulumi.Input[str]] = None,
                 brand_id: Optional[pulumi.Input[int]] = None,
                 configuration: Optional[pulumi.Input[pulumi.InputType['AppConfigurationArgs']]] = None,
                 connector_id: Optional[pulumi.Input[int]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enforcement_point: Optional[pulumi.Input[pulumi.InputType['AppEnforcementPointArgs']]] = None,
                 icon_url: Optional[pulumi.Input[str]] = None,
                 login_config: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[pulumi.InputType['AppParametersArgs']]] = None,
                 policy_id: Optional[pulumi.Input[int]] = None,
                 provisioning: Optional[pulumi.Input[pulumi.InputType['AppProvisioningArgs']]] = None,
                 role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 sso: Optional[pulumi.Input[pulumi.InputType['AppSsoArgs']]] = None,
                 tab_id: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 visible: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Create a App resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_assumed_signin: Indicates whether or not administrators can access the app as a user that they have assumed control over.
        :param pulumi.Input[int] auth_method: An ID indicating the type of app: - 0: Password - 1: OpenId - 2: SAML - 3: API - 4: Google - 6: Forms Based App - 7:
               WSFED - 8: OpenId Connect
        :param pulumi.Input[pulumi.InputType['AppConfigurationArgs']] configuration: Only apply configurations that are applicable to the type of app
        :param pulumi.Input[int] connector_id: ID of the connector to base the app from.
        :param pulumi.Input[str] created_at: the date the app was created
        :param pulumi.Input[str] description: Freeform description of the app.
        :param pulumi.Input[pulumi.InputType['AppEnforcementPointArgs']] enforcement_point: For apps that connect to a OneLogin Access Enforcement Point the following enforcement_point object will be included
               with the app payload.
        :param pulumi.Input[str] icon_url: A link to the apps icon url
        :param pulumi.Input[str] name: The name of the app.
        :param pulumi.Input[str] notes: Freeform notes about the app.
        :param pulumi.Input[int] policy_id: The security policy assigned to the app.
        :param pulumi.Input[pulumi.InputType['AppProvisioningArgs']] provisioning: Indicates if provisioning is enabled for this app.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] role_ids: List of Role IDs that are assigned to the app. On App Create or Update the entire array is replaced with the values
               provided.
        :param pulumi.Input[pulumi.InputType['AppSsoArgs']] sso: The attributes included in the sso section are determined by the type of app. All of the attributes of the `sso` object
               are read only.
        :param pulumi.Input[int] tab_id: ID of the OneLogin portal tab that the app is assigned to.
        :param pulumi.Input[str] updated_at: the date the app was last updated
        :param pulumi.Input[bool] visible: Indicates if the app is visible in the OneLogin portal.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AppArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Create a App resource with the given unique name, props, and options.
        :param str resource_name: The name of the resource.
        :param AppArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_assumed_signin: Optional[pulumi.Input[bool]] = None,
                 auth_method: Optional[pulumi.Input[int]] = None,
                 auth_method_description: Optional[pulumi.Input[str]] = None,
                 brand_id: Optional[pulumi.Input[int]] = None,
                 configuration: Optional[pulumi.Input[pulumi.InputType['AppConfigurationArgs']]] = None,
                 connector_id: Optional[pulumi.Input[int]] = None,
                 created_at: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enforcement_point: Optional[pulumi.Input[pulumi.InputType['AppEnforcementPointArgs']]] = None,
                 icon_url: Optional[pulumi.Input[str]] = None,
                 login_config: Optional[pulumi.Input[int]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 notes: Optional[pulumi.Input[str]] = None,
                 parameters: Optional[pulumi.Input[pulumi.InputType['AppParametersArgs']]] = None,
                 policy_id: Optional[pulumi.Input[int]] = None,
                 provisioning: Optional[pulumi.Input[pulumi.InputType['AppProvisioningArgs']]] = None,
                 role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
                 sso: Optional[pulumi.Input[pulumi.InputType['AppSsoArgs']]] = None,
                 tab_id: Optional[pulumi.Input[int]] = None,
                 updated_at: Optional[pulumi.Input[str]] = None,
                 visible: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppArgs.__new__(AppArgs)

            __props__.__dict__["allow_assumed_signin"] = allow_assumed_signin
            __props__.__dict__["auth_method"] = auth_method
            __props__.__dict__["auth_method_description"] = auth_method_description
            __props__.__dict__["brand_id"] = brand_id
            __props__.__dict__["configuration"] = configuration
            if connector_id is None and not opts.urn:
                raise TypeError("Missing required property 'connector_id'")
            __props__.__dict__["connector_id"] = connector_id
            __props__.__dict__["created_at"] = created_at
            __props__.__dict__["description"] = description
            __props__.__dict__["enforcement_point"] = enforcement_point
            __props__.__dict__["icon_url"] = icon_url
            __props__.__dict__["login_config"] = login_config
            __props__.__dict__["name"] = name
            __props__.__dict__["notes"] = notes
            __props__.__dict__["parameters"] = parameters
            __props__.__dict__["policy_id"] = policy_id
            __props__.__dict__["provisioning"] = provisioning
            __props__.__dict__["role_ids"] = role_ids
            __props__.__dict__["sso"] = sso
            __props__.__dict__["tab_id"] = tab_id
            __props__.__dict__["updated_at"] = updated_at
            __props__.__dict__["visible"] = visible
        super(App, __self__).__init__(
            'onelogin:index/app:App',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_assumed_signin: Optional[pulumi.Input[bool]] = None,
            auth_method: Optional[pulumi.Input[int]] = None,
            auth_method_description: Optional[pulumi.Input[str]] = None,
            brand_id: Optional[pulumi.Input[int]] = None,
            configuration: Optional[pulumi.Input[pulumi.InputType['AppConfigurationArgs']]] = None,
            connector_id: Optional[pulumi.Input[int]] = None,
            created_at: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            enforcement_point: Optional[pulumi.Input[pulumi.InputType['AppEnforcementPointArgs']]] = None,
            icon_url: Optional[pulumi.Input[str]] = None,
            login_config: Optional[pulumi.Input[int]] = None,
            name: Optional[pulumi.Input[str]] = None,
            notes: Optional[pulumi.Input[str]] = None,
            parameters: Optional[pulumi.Input[pulumi.InputType['AppParametersArgs']]] = None,
            policy_id: Optional[pulumi.Input[int]] = None,
            provisioning: Optional[pulumi.Input[pulumi.InputType['AppProvisioningArgs']]] = None,
            role_ids: Optional[pulumi.Input[Sequence[pulumi.Input[int]]]] = None,
            sso: Optional[pulumi.Input[pulumi.InputType['AppSsoArgs']]] = None,
            tab_id: Optional[pulumi.Input[int]] = None,
            updated_at: Optional[pulumi.Input[str]] = None,
            visible: Optional[pulumi.Input[bool]] = None) -> 'App':
        """
        Get an existing App resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[bool] allow_assumed_signin: Indicates whether or not administrators can access the app as a user that they have assumed control over.
        :param pulumi.Input[int] auth_method: An ID indicating the type of app: - 0: Password - 1: OpenId - 2: SAML - 3: API - 4: Google - 6: Forms Based App - 7:
               WSFED - 8: OpenId Connect
        :param pulumi.Input[pulumi.InputType['AppConfigurationArgs']] configuration: Only apply configurations that are applicable to the type of app
        :param pulumi.Input[int] connector_id: ID of the connector to base the app from.
        :param pulumi.Input[str] created_at: the date the app was created
        :param pulumi.Input[str] description: Freeform description of the app.
        :param pulumi.Input[pulumi.InputType['AppEnforcementPointArgs']] enforcement_point: For apps that connect to a OneLogin Access Enforcement Point the following enforcement_point object will be included
               with the app payload.
        :param pulumi.Input[str] icon_url: A link to the apps icon url
        :param pulumi.Input[str] name: The name of the app.
        :param pulumi.Input[str] notes: Freeform notes about the app.
        :param pulumi.Input[int] policy_id: The security policy assigned to the app.
        :param pulumi.Input[pulumi.InputType['AppProvisioningArgs']] provisioning: Indicates if provisioning is enabled for this app.
        :param pulumi.Input[Sequence[pulumi.Input[int]]] role_ids: List of Role IDs that are assigned to the app. On App Create or Update the entire array is replaced with the values
               provided.
        :param pulumi.Input[pulumi.InputType['AppSsoArgs']] sso: The attributes included in the sso section are determined by the type of app. All of the attributes of the `sso` object
               are read only.
        :param pulumi.Input[int] tab_id: ID of the OneLogin portal tab that the app is assigned to.
        :param pulumi.Input[str] updated_at: the date the app was last updated
        :param pulumi.Input[bool] visible: Indicates if the app is visible in the OneLogin portal.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppState.__new__(_AppState)

        __props__.__dict__["allow_assumed_signin"] = allow_assumed_signin
        __props__.__dict__["auth_method"] = auth_method
        __props__.__dict__["auth_method_description"] = auth_method_description
        __props__.__dict__["brand_id"] = brand_id
        __props__.__dict__["configuration"] = configuration
        __props__.__dict__["connector_id"] = connector_id
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["description"] = description
        __props__.__dict__["enforcement_point"] = enforcement_point
        __props__.__dict__["icon_url"] = icon_url
        __props__.__dict__["login_config"] = login_config
        __props__.__dict__["name"] = name
        __props__.__dict__["notes"] = notes
        __props__.__dict__["parameters"] = parameters
        __props__.__dict__["policy_id"] = policy_id
        __props__.__dict__["provisioning"] = provisioning
        __props__.__dict__["role_ids"] = role_ids
        __props__.__dict__["sso"] = sso
        __props__.__dict__["tab_id"] = tab_id
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["visible"] = visible
        return App(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowAssumedSignin")
    def allow_assumed_signin(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether or not administrators can access the app as a user that they have assumed control over.
        """
        return pulumi.get(self, "allow_assumed_signin")

    @property
    @pulumi.getter(name="authMethod")
    def auth_method(self) -> pulumi.Output[Optional[int]]:
        """
        An ID indicating the type of app: - 0: Password - 1: OpenId - 2: SAML - 3: API - 4: Google - 6: Forms Based App - 7:
        WSFED - 8: OpenId Connect
        """
        return pulumi.get(self, "auth_method")

    @property
    @pulumi.getter(name="authMethodDescription")
    def auth_method_description(self) -> pulumi.Output[str]:
        return pulumi.get(self, "auth_method_description")

    @property
    @pulumi.getter(name="brandId")
    def brand_id(self) -> pulumi.Output[Optional[int]]:
        return pulumi.get(self, "brand_id")

    @property
    @pulumi.getter
    def configuration(self) -> pulumi.Output['outputs.AppConfiguration']:
        """
        Only apply configurations that are applicable to the type of app
        """
        return pulumi.get(self, "configuration")

    @property
    @pulumi.getter(name="connectorId")
    def connector_id(self) -> pulumi.Output[int]:
        """
        ID of the connector to base the app from.
        """
        return pulumi.get(self, "connector_id")

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[str]:
        """
        the date the app was created
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Freeform description of the app.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enforcementPoint")
    def enforcement_point(self) -> pulumi.Output[Optional['outputs.AppEnforcementPoint']]:
        """
        For apps that connect to a OneLogin Access Enforcement Point the following enforcement_point object will be included
        with the app payload.
        """
        return pulumi.get(self, "enforcement_point")

    @property
    @pulumi.getter(name="iconUrl")
    def icon_url(self) -> pulumi.Output[Optional[str]]:
        """
        A link to the apps icon url
        """
        return pulumi.get(self, "icon_url")

    @property
    @pulumi.getter(name="loginConfig")
    def login_config(self) -> pulumi.Output[int]:
        return pulumi.get(self, "login_config")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        The name of the app.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def notes(self) -> pulumi.Output[Optional[str]]:
        """
        Freeform notes about the app.
        """
        return pulumi.get(self, "notes")

    @property
    @pulumi.getter
    def parameters(self) -> pulumi.Output['outputs.AppParameters']:
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter(name="policyId")
    def policy_id(self) -> pulumi.Output[Optional[int]]:
        """
        The security policy assigned to the app.
        """
        return pulumi.get(self, "policy_id")

    @property
    @pulumi.getter
    def provisioning(self) -> pulumi.Output[Optional['outputs.AppProvisioning']]:
        """
        Indicates if provisioning is enabled for this app.
        """
        return pulumi.get(self, "provisioning")

    @property
    @pulumi.getter(name="roleIds")
    def role_ids(self) -> pulumi.Output[Optional[Sequence[int]]]:
        """
        List of Role IDs that are assigned to the app. On App Create or Update the entire array is replaced with the values
        provided.
        """
        return pulumi.get(self, "role_ids")

    @property
    @pulumi.getter
    def sso(self) -> pulumi.Output['outputs.AppSso']:
        """
        The attributes included in the sso section are determined by the type of app. All of the attributes of the `sso` object
        are read only.
        """
        return pulumi.get(self, "sso")

    @property
    @pulumi.getter(name="tabId")
    def tab_id(self) -> pulumi.Output[Optional[int]]:
        """
        ID of the OneLogin portal tab that the app is assigned to.
        """
        return pulumi.get(self, "tab_id")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[str]:
        """
        the date the app was last updated
        """
        return pulumi.get(self, "updated_at")

    @property
    @pulumi.getter
    def visible(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates if the app is visible in the OneLogin portal.
        """
        return pulumi.get(self, "visible")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetRolesResult',
    'AwaitableGetRolesResult',
    'get_roles',
    'get_roles_output',
]

@pulumi.output_type
class GetRolesResult:
    """
    A collection of values returned by getRoles.
    """
    def __init__(__self__, admins=None, apps=None, filters=None, id=None, name=None, users=None):
        if admins and not isinstance(admins, list):
            raise TypeError("Expected argument 'admins' to be a list")
        pulumi.set(__self__, "admins", admins)
        if apps and not isinstance(apps, list):
            raise TypeError("Expected argument 'apps' to be a list")
        pulumi.set(__self__, "apps", apps)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def admins(self) -> Sequence[int]:
        return pulumi.get(self, "admins")

    @property
    @pulumi.getter
    def apps(self) -> Sequence[int]:
        return pulumi.get(self, "apps")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetRolesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def users(self) -> Sequence[int]:
        return pulumi.get(self, "users")


class AwaitableGetRolesResult(GetRolesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRolesResult(
            admins=self.admins,
            apps=self.apps,
            filters=self.filters,
            id=self.id,
            name=self.name,
            users=self.users)


def get_roles(admins: Optional[Sequence[int]] = None,
              apps: Optional[Sequence[int]] = None,
              filters: Optional[Sequence[pulumi.InputType['GetRolesFilterArgs']]] = None,
              name: Optional[str] = None,
              users: Optional[Sequence[int]] = None,
              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRolesResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['admins'] = admins
    __args__['apps'] = apps
    __args__['filters'] = filters
    __args__['name'] = name
    __args__['users'] = users
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('onelogin:roles/getRoles:getRoles', __args__, opts=opts, typ=GetRolesResult).value

    return AwaitableGetRolesResult(
        admins=pulumi.get(__ret__, 'admins'),
        apps=pulumi.get(__ret__, 'apps'),
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        users=pulumi.get(__ret__, 'users'))


@_utilities.lift_output_func(get_roles)
def get_roles_output(admins: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                     apps: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                     filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetRolesFilterArgs']]]]] = None,
                     name: Optional[pulumi.Input[Optional[str]]] = None,
                     users: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetRolesResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetInstanceResult',
    'AwaitableGetInstanceResult',
    'get_instance',
    'get_instance_output',
]

@pulumi.output_type
class GetInstanceResult:
    """
    A collection of values returned by getInstance.
    """
    def __init__(__self__, admins=None, apps=None, id=None, name=None, users=None):
        if admins and not isinstance(admins, list):
            raise TypeError("Expected argument 'admins' to be a list")
        pulumi.set(__self__, "admins", admins)
        if apps and not isinstance(apps, list):
            raise TypeError("Expected argument 'apps' to be a list")
        pulumi.set(__self__, "apps", apps)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def admins(self) -> Sequence[int]:
        return pulumi.get(self, "admins")

    @property
    @pulumi.getter
    def apps(self) -> Sequence[int]:
        return pulumi.get(self, "apps")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def users(self) -> Sequence[int]:
        return pulumi.get(self, "users")


class AwaitableGetInstanceResult(GetInstanceResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstanceResult(
            admins=self.admins,
            apps=self.apps,
            id=self.id,
            name=self.name,
            users=self.users)


def get_instance(admins: Optional[Sequence[int]] = None,
                 apps: Optional[Sequence[int]] = None,
                 id: Optional[str] = None,
                 name: Optional[str] = None,
                 users: Optional[Sequence[int]] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstanceResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['admins'] = admins
    __args__['apps'] = apps
    __args__['id'] = id
    __args__['name'] = name
    __args__['users'] = users
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('onelogin:roles/getInstance:getInstance', __args__, opts=opts, typ=GetInstanceResult).value

    return AwaitableGetInstanceResult(
        admins=pulumi.get(__ret__, 'admins'),
        apps=pulumi.get(__ret__, 'apps'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        users=pulumi.get(__ret__, 'users'))


@_utilities.lift_output_func(get_instance)
def get_instance_output(admins: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                        apps: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                        id: Optional[pulumi.Input[str]] = None,
                        name: Optional[pulumi.Input[Optional[str]]] = None,
                        users: Optional[pulumi.Input[Optional[Sequence[int]]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstanceResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetDevicesResult',
    'AwaitableGetDevicesResult',
    'get_devices',
    'get_devices_output',
]

@pulumi.output_type
class GetDevicesResult:
    """
    A collection of values returned by getDevices.
    """
    def __init__(__self__, auth_factor_name=None, default=None, device_id=None, filters=None, id=None, type_display_name=None, user_display_name=None, users_id=None):
        if auth_factor_name and not isinstance(auth_factor_name, str):
            raise TypeError("Expected argument 'auth_factor_name' to be a str")
        pulumi.set(__self__, "auth_factor_name", auth_factor_name)
        if default and not isinstance(default, bool):
            raise TypeError("Expected argument 'default' to be a bool")
        pulumi.set(__self__, "default", default)
        if device_id and not isinstance(device_id, str):
            raise TypeError("Expected argument 'device_id' to be a str")
        pulumi.set(__self__, "device_id", device_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if type_display_name and not isinstance(type_display_name, str):
            raise TypeError("Expected argument 'type_display_name' to be a str")
        pulumi.set(__self__, "type_display_name", type_display_name)
        if user_display_name and not isinstance(user_display_name, str):
            raise TypeError("Expected argument 'user_display_name' to be a str")
        pulumi.set(__self__, "user_display_name", user_display_name)
        if users_id and not isinstance(users_id, str):
            raise TypeError("Expected argument 'users_id' to be a str")
        pulumi.set(__self__, "users_id", users_id)

    @property
    @pulumi.getter(name="authFactorName")
    def auth_factor_name(self) -> str:
        return pulumi.get(self, "auth_factor_name")

    @property
    @pulumi.getter
    def default(self) -> bool:
        return pulumi.get(self, "default")

    @property
    @pulumi.getter(name="deviceId")
    def device_id(self) -> str:
        return pulumi.get(self, "device_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetDevicesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="typeDisplayName")
    def type_display_name(self) -> str:
        return pulumi.get(self, "type_display_name")

    @property
    @pulumi.getter(name="userDisplayName")
    def user_display_name(self) -> str:
        return pulumi.get(self, "user_display_name")

    @property
    @pulumi.getter(name="usersId")
    def users_id(self) -> str:
        return pulumi.get(self, "users_id")


class AwaitableGetDevicesResult(GetDevicesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDevicesResult(
            auth_factor_name=self.auth_factor_name,
            default=self.default,
            device_id=self.device_id,
            filters=self.filters,
            id=self.id,
            type_display_name=self.type_display_name,
            user_display_name=self.user_display_name,
            users_id=self.users_id)


def get_devices(auth_factor_name: Optional[str] = None,
                default: Optional[bool] = None,
                device_id: Optional[str] = None,
                filters: Optional[Sequence[pulumi.InputType['GetDevicesFilterArgs']]] = None,
                type_display_name: Optional[str] = None,
                user_display_name: Optional[str] = None,
                users_id: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDevicesResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['authFactorName'] = auth_factor_name
    __args__['default'] = default
    __args__['deviceId'] = device_id
    __args__['filters'] = filters
    __args__['typeDisplayName'] = type_display_name
    __args__['userDisplayName'] = user_display_name
    __args__['usersId'] = users_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('onelogin:users/getDevices:getDevices', __args__, opts=opts, typ=GetDevicesResult).value

    return AwaitableGetDevicesResult(
        auth_factor_name=pulumi.get(__ret__, 'auth_factor_name'),
        default=pulumi.get(__ret__, 'default'),
        device_id=pulumi.get(__ret__, 'device_id'),
        filters=pulumi.get(__ret__, 'filters'),
        id=pulumi.get(__ret__, 'id'),
        type_display_name=pulumi.get(__ret__, 'type_display_name'),
        user_display_name=pulumi.get(__ret__, 'user_display_name'),
        users_id=pulumi.get(__ret__, 'users_id'))


@_utilities.lift_output_func(get_devices)
def get_devices_output(auth_factor_name: Optional[pulumi.Input[Optional[str]]] = None,
                       default: Optional[pulumi.Input[Optional[bool]]] = None,
                       device_id: Optional[pulumi.Input[Optional[str]]] = None,
                       filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetDevicesFilterArgs']]]]] = None,
                       type_display_name: Optional[pulumi.Input[Optional[str]]] = None,
                       user_display_name: Optional[pulumi.Input[Optional[str]]] = None,
                       users_id: Optional[pulumi.Input[str]] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetDevicesResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAppsResult',
    'AwaitableGetAppsResult',
    'get_apps',
    'get_apps_output',
]

@pulumi.output_type
class GetAppsResult:
    """
    A collection of values returned by getApps.
    """
    def __init__(__self__, filters=None, icon_url=None, id=None, name=None, roles_id=None):
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if icon_url and not isinstance(icon_url, str):
            raise TypeError("Expected argument 'icon_url' to be a str")
        pulumi.set(__self__, "icon_url", icon_url)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if roles_id and not isinstance(roles_id, str):
            raise TypeError("Expected argument 'roles_id' to be a str")
        pulumi.set(__self__, "roles_id", roles_id)

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAppsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="iconUrl")
    def icon_url(self) -> str:
        return pulumi.get(self, "icon_url")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="rolesId")
    def roles_id(self) -> str:
        return pulumi.get(self, "roles_id")


class AwaitableGetAppsResult(GetAppsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppsResult(
            filters=self.filters,
            icon_url=self.icon_url,
            id=self.id,
            name=self.name,
            roles_id=self.roles_id)


def get_apps(filters: Optional[Sequence[pulumi.InputType['GetAppsFilterArgs']]] = None,
             icon_url: Optional[str] = None,
             name: Optional[str] = None,
             roles_id: Optional[str] = None,
             opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppsResult:
    """
    Use this data source to access information about an existing resource.
    """
    __args__ = dict()
    __args__['filters'] = filters
    __args__['iconUrl'] = icon_url
    __args__['name'] = name
    __args__['rolesId'] = roles_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('onelogin:roles/getApps:getApps', __args__, opts=opts, typ=GetAppsResult).value

    return AwaitableGetAppsResult(
        filters=pulumi.get(__ret__, 'filters'),
        icon_url=pulumi.get(__ret__, 'icon_url'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        roles_id=pulumi.get(__ret__, 'roles_id'))


@_utilities.lift_output_func(get_apps)
def get_apps_output(filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAppsFilterArgs']]]]] = None,
                    icon_url: Optional[pulumi.Input[Optional[str]]] = None,
                    name: Optional[pulumi.Input[Optional[str]]] = None,
                    roles_id: Optional[pulumi.Input[str]] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAppsResult]:
    """
    Use this data source to access information about an existing resource.
    """
    ...
